==> grdc_0.3.0.orig.tar.gz: grdc-0.3.0/src/grdcfile.h <==
/*
 * Grdc - GTK+/Gnome Remote Desktop Client
 * Copyright (C) 2009 - Vic Lee 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 

#ifndef __GRDCFILE_H__
#define __GRDCFILE_H__

G_BEGIN_DECLS

typedef struct _GrdcFile
{
    gchar *filename;
    gchar *name;
    gchar *group;
    gchar *server;
    gchar *protocol;
    gchar *username;
    gchar *password;
    gchar *domain;
    gchar *clientname;
    gchar *resolution;
    gchar *colordepth;
    gchar *quality;
    gboolean bitmapcaching;
    gboolean compression;
    gboolean showcursor;
    gboolean viewonly;

    gint viewmode;

    gint resolution_width;
    gint resolution_height;
} GrdcFile;

/* Create a empty .grdc file */
GrdcFile* grdc_file_new (void);
GrdcFile* grdc_file_new_temp (void);
/* Load a new .grdc file and return the allocated GrdcFile object */
GrdcFile* grdc_file_load (const gchar *filename);
/* Create or overwrite the .grdc file */
void grdc_file_save (GrdcFile *gf);
/* Free the GrdcFile object */
void grdc_file_free (GrdcFile *grdcfile);
/* Duplicate a GrdcFile object */
GrdcFile* grdc_file_dup (GrdcFile *grdcfile);
/* Update the screen width and height members */
void grdc_file_update_screen_resolution (GrdcFile *grdcfile);

G_END_DECLS

#endif  /* __GRDCFILE_H__  */

==> grdc_0.6.0.orig.tar.gz: grdc-0.6.0/src/grdcfile.h <==
/*
 * Grdc - GTK+/Gnome Remote Desktop Client
 * Copyright (C) 2009 - Vic Lee 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 

#ifndef __GRDCFILE_H__
#define __GRDCFILE_H__

G_BEGIN_DECLS

enum
{
    SSH_AUTH_PASSWORD,
    SSH_AUTH_PUBLICKEY
};

#define TOOLBAR_OPACITY_LEVEL 8
#define TOOLBAR_OPACITY_MIN 0.2

typedef struct _GrdcFile
{
    /* Profile settings */
    gchar *filename;
    gchar *name;
    gchar *group;

    /* Protocol settings */
    gchar *server;
    gchar *protocol;
    gchar *username;
    gchar *password;
    gchar *domain;
    gchar *clientname;
    gchar *resolution;
    gchar *keymap;
    gchar *gkeymap;
    gchar *exec;
    gchar *execpath;
    gchar *arguments;
    gint colordepth;
    gint quality;
    gint listenport;
    gint sharefolder;
    gint hscale;
    gint vscale;
    gboolean bitmapcaching;
    gboolean compression;
    gboolean showcursor;
    gboolean viewonly;
    gboolean console;
    gboolean disableserverinput;
    gboolean aspectscale;

    /* SSH settings */
    gboolean ssh_enabled;
    gchar *ssh_server;
    gint ssh_auth;
    gchar *ssh_username;
    gchar *ssh_privatekey;
    gchar *ssh_charset;

    /* Run-time settings */
    gint viewmode;
    gboolean scale;
    gboolean keyboard_grab;

    gint window_width;
    gint window_height;
    gboolean window_maximize;

    gint toolbar_opacity;

    gint resolution_width;
    gint resolution_height;
} GrdcFile;

extern const gpointer colordepth_list[];
extern const gpointer quality_list[];

/* Create a empty .grdc file */
GrdcFile* grdc_file_new (void);
GrdcFile* grdc_file_new_temp (void);
/* Load a new .grdc file and return the allocated GrdcFile object */
GrdcFile* grdc_file_load (const gchar *filename);
/* Create or overwrite the .grdc file */
void grdc_file_save (GrdcFile *gf);
/* Free the GrdcFile object */
void grdc_file_free (GrdcFile *grdcfile);
/* Duplicate a GrdcFile object */
GrdcFile* grdc_file_dup (GrdcFile *grdcfile);
/* Update the screen width and height members */
void grdc_file_update_screen_resolution (GrdcFile *grdcfile);
/* Get the protocol icon pixbuf */
GdkPixbuf* grdc_file_get_icon (GrdcFile *grdcfile, gint size);
/* Is an incoming protocol */
gboolean grdc_file_is_incoming (GrdcFile *grdcfile);

G_END_DECLS

#endif  /* __GRDCFILE_H__  */
